==> xlniuxdata-vipgame-1.0.1-20150129.140049-6-sources.jar: com/xunlei/niux/data/vipgame/vo/LinkInfo.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;

@Table(tableName="linkinfo",pkFieldName="linkid",pkFieldAssign=false)
public class LinkInfo {
	private Integer linkid;
	private String linklocid;
	private String linktitle;
	private String linkdesc;
	private String linkcontents;
	private Boolean isredtitle;
	private Boolean isboldtitle;
	private Boolean isjump;
	private String linkurl;
	private String picurl;
	private String validdatetime;
	private String invaliddatetime;
	private String displayorder;
	private String ext1;
	private String ext2;
	private String ext3;
    private String ext4;
    private String ext5;
    private String ext6;
    private String ext7;
	@Column(columnName="validdatetime",isWhereColumn=true,operator=Operator.GE)
	private String fromvaliddatetime;
	@Column(columnName="validdatetime",isWhereColumn=true,operator=Operator.LT)
	private String tovaliddatetime;
	@Column(columnName="invaliddatetime",isWhereColumn=true,operator=Operator.GE)
	private String frominvaliddatetime;
	@Column(columnName="invaliddatetime",isWhereColumn=true,operator=Operator.LT)
	private String toinvaliddatetime;
	private String inputby;
	private String inputtime;
	private String editby;
	private String edittime;
	private String gameid;
	private Boolean istest;
	private String gameidbytuijian;
	private String linklocgroupid;
	private String smallpicurl;
	private Integer displaysort;
	private Boolean isvalid;
	
	public Integer getDisplaysort() {
		return displaysort;
	}
	public void setDisplaysort(Integer displaysort) {
		this.displaysort = displaysort;
	}
	public Boolean getIsvalid() {
		return isvalid;
	}
	public void setIsvalid(Boolean isvalid) {
		this.isvalid = isvalid;
	}
	public String getSmallpicurl() {
		return smallpicurl;
	}
	public void setSmallpicurl(String smallpicurl) {
		this.smallpicurl = smallpicurl;
	}
	public String getLinklocgroupid() {
		return linklocgroupid;
	}
	public void setLinklocgroupid(String linklocgroupid) {
		this.linklocgroupid = linklocgroupid;
	}
	public String getInputby() {
		return inputby;
	}
	public void setInputby(String inputby) {
		this.inputby = inputby;
	}
	public String getInputtime() {
		return inputtime;
	}
	public void setInputtime(String inputtime) {
		this.inputtime = inputtime;
	}
	public String getEditby() {
		return editby;
	}
	public void setEditby(String editby) {
		this.editby = editby;
	}
	public String getEdittime() {
		return edittime;
	}
	public void setEdittime(String edittime) {
		this.edittime = edittime;
	}
	public Integer getLinkid() {
		return linkid;
	}
	public void setLinkid(Integer linkid) {
		this.linkid = linkid;
	}
	public String getLinklocid() {
		return linklocid;
	}
	public void setLinklocid(String linklocid) {
		this.linklocid = linklocid;
	}
	public String getLinktitle() {
		return linktitle;
	}
	public void setLinktitle(String linktitle) {
		this.linktitle = linktitle;
	}
	public String getLinkdesc() {
		return linkdesc;
	}
	public void setLinkdesc(String linkdesc) {
		this.linkdesc = linkdesc;
	}
	public String getLinkcontents() {
		return linkcontents;
	}
	public void setLinkcontents(String linkcontents) {
		this.linkcontents = linkcontents;
	}
	public Boolean getIsredtitle() {
		return isredtitle;
	}
	public void setIsredtitle(Boolean isredtitle) {
		this.isredtitle = isredtitle;
	}
	public Boolean getIsboldtitle() {
		return isboldtitle;
	}
	public void setIsboldtitle(Boolean isboldtitle) {
		this.isboldtitle = isboldtitle;
	}
	public Boolean getIsjump() {
		return isjump;
	}
	public void setIsjump(Boolean isjump) {
		this.isjump = isjump;
	}
	public String getLinkurl() {
		return linkurl;
	}
	public void setLinkurl(String linkurl) {
		this.linkurl = linkurl;
	}
	public String getPicurl() {
		return picurl;
	}
	public void setPicurl(String picurl) {
		this.picurl = picurl;
	}
	public String getValiddatetime() {
		return validdatetime;
	}
	public void setValiddatetime(String validdatetime) {
		this.validdatetime = validdatetime;
	}
	public String getInvaliddatetime() {
		return invaliddatetime;
	}
	public void setInvaliddatetime(String invaliddatetime) {
		this.invaliddatetime = invaliddatetime;
	}
	public String getDisplayorder() {
		return displayorder;
	}
	public void setDisplayorder(String displayorder) {
		this.displayorder = displayorder;
	}
	public String getExt1() {
		return ext1;
	}
	public void setExt1(String ext1) {
		this.ext1 = ext1;
	}
	public String getExt2() {
		return ext2;
	}
	public void setExt2(String ext2) {
		this.ext2 = ext2;
	}
	public String getExt3() {
		return ext3;
	}
	public void setExt3(String ext3) {
		this.ext3 = ext3;
	}

    public String getExt4() {
        return ext4;
    }

    public void setExt4(String ext4) {
        this.ext4 = ext4;
    }

    public String getExt5() {
        return ext5;
    }

    public void setExt5(String ext5) {
        this.ext5 = ext5;
    }

    public String getExt6() {
        return ext6;
    }

    public void setExt6(String ext6) {
        this.ext6 = ext6;
    }

    public String getExt7() {
        return ext7;
    }

    public void setExt7(String ext7) {
        this.ext7 = ext7;
    }

    public String getFromvaliddatetime() {
		return fromvaliddatetime;
	}
	public void setFromvaliddatetime(String fromvaliddatetime) {
		this.fromvaliddatetime = fromvaliddatetime;
	}
	public String getTovaliddatetime() {
		return tovaliddatetime;
	}
	public void setTovaliddatetime(String tovaliddatetime) {
		this.tovaliddatetime = tovaliddatetime;
	}
	public String getFrominvaliddatetime() {
		return frominvaliddatetime;
	}
	public void setFrominvaliddatetime(String frominvaliddatetime) {
		this.frominvaliddatetime = frominvaliddatetime;
	}
	public String getToinvaliddatetime() {
		return toinvaliddatetime;
	}
	public void setToinvaliddatetime(String toinvaliddatetime) {
		this.toinvaliddatetime = toinvaliddatetime;
	}
	public String getGameid() {
		return gameid;
	}
	public void setGameid(String gameid) {
		this.gameid = gameid;
	}
	public Boolean getIstest() {
		return istest;
	}
	public void setIstest(Boolean istest) {
		this.istest = istest;
	}
	public String getGameidbytuijian() {
		return gameidbytuijian;
	}
	public void setGameidbytuijian(String gameidbytuijian) {
		this.gameidbytuijian = gameidbytuijian;
	}
	
}

==> xlniuxdata-vipgame-1.0.39-20151203.044132-10-sources.jar: com/xunlei/niux/data/vipgame/vo/LinkInfo.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;

@Table(tableName="linkinfo",pkFieldName="linkid",pkFieldAssign=false)
public class LinkInfo {
	private Integer linkid;
	private String linklocid;
	private String linktitle;
	private String linkdesc;
	private String linkcontents;
	private Boolean isredtitle;
	private Boolean isboldtitle;
	private Boolean isjump;
	private String linkurl;
	private String picurl;
	private String validdatetime;
	private String invaliddatetime;
	private String displayorder;
	private String ext1;
	private String ext2;
	private String ext3;
    private String ext4;
    private String ext5;
    private String ext6;
    private String ext7;
    private Double ext8;

    @Column(columnName="validdatetime",isWhereColumn=true,operator=Operator.GE)
	private String fromvaliddatetime;
	@Column(columnName="validdatetime",isWhereColumn=true,operator=Operator.LT)
	private String tovaliddatetime;
	@Column(columnName="invaliddatetime",isWhereColumn=true,operator=Operator.GE)
	private String frominvaliddatetime;
	@Column(columnName="invaliddatetime",isWhereColumn=true,operator=Operator.LT)
	private String toinvaliddatetime;
	private String inputby;
	private String inputtime;
	private String editby;
	private String edittime;
	private String gameid;
	private Boolean istest;
	private String gameidbytuijian;
	private String linklocgroupid;
	private String smallpicurl;
	private Integer displaysort;
	private Boolean isvalid;
	
	public Integer getDisplaysort() {
		return displaysort;
	}
	public void setDisplaysort(Integer displaysort) {
		this.displaysort = displaysort;
	}
	public Boolean getIsvalid() {
		return isvalid;
	}
	public void setIsvalid(Boolean isvalid) {
		this.isvalid = isvalid;
	}
	public String getSmallpicurl() {
		return smallpicurl;
	}
	public void setSmallpicurl(String smallpicurl) {
		this.smallpicurl = smallpicurl;
	}
	public String getLinklocgroupid() {
		return linklocgroupid;
	}
	public void setLinklocgroupid(String linklocgroupid) {
		this.linklocgroupid = linklocgroupid;
	}
	public String getInputby() {
		return inputby;
	}
	public void setInputby(String inputby) {
		this.inputby = inputby;
	}
	public String getInputtime() {
		return inputtime;
	}
	public void setInputtime(String inputtime) {
		this.inputtime = inputtime;
	}
	public String getEditby() {
		return editby;
	}
	public void setEditby(String editby) {
		this.editby = editby;
	}
	public String getEdittime() {
		return edittime;
	}
	public void setEdittime(String edittime) {
		this.edittime = edittime;
	}
	public Integer getLinkid() {
		return linkid;
	}
	public void setLinkid(Integer linkid) {
		this.linkid = linkid;
	}
	public String getLinklocid() {
		return linklocid;
	}
	public void setLinklocid(String linklocid) {
		this.linklocid = linklocid;
	}
	public String getLinktitle() {
		return linktitle;
	}
	public void setLinktitle(String linktitle) {
		this.linktitle = linktitle;
	}
	public String getLinkdesc() {
		return linkdesc;
	}
	public void setLinkdesc(String linkdesc) {
		this.linkdesc = linkdesc;
	}
	public String getLinkcontents() {
		return linkcontents;
	}
	public void setLinkcontents(String linkcontents) {
		this.linkcontents = linkcontents;
	}
	public Boolean getIsredtitle() {
		return isredtitle;
	}
	public void setIsredtitle(Boolean isredtitle) {
		this.isredtitle = isredtitle;
	}
	public Boolean getIsboldtitle() {
		return isboldtitle;
	}
	public void setIsboldtitle(Boolean isboldtitle) {
		this.isboldtitle = isboldtitle;
	}
	public Boolean getIsjump() {
		return isjump;
	}
	public void setIsjump(Boolean isjump) {
		this.isjump = isjump;
	}
	public String getLinkurl() {
		return linkurl;
	}
	public void setLinkurl(String linkurl) {
		this.linkurl = linkurl;
	}
	public String getPicurl() {
		return picurl;
	}
	public void setPicurl(String picurl) {
		this.picurl = picurl;
	}
	public String getValiddatetime() {
		return validdatetime;
	}
	public void setValiddatetime(String validdatetime) {
		this.validdatetime = validdatetime;
	}
	public String getInvaliddatetime() {
		return invaliddatetime;
	}
	public void setInvaliddatetime(String invaliddatetime) {
		this.invaliddatetime = invaliddatetime;
	}
	public String getDisplayorder() {
		return displayorder;
	}
	public void setDisplayorder(String displayorder) {
		this.displayorder = displayorder;
	}
	public String getExt1() {
		return ext1;
	}
	public void setExt1(String ext1) {
		this.ext1 = ext1;
	}
	public String getExt2() {
		return ext2;
	}
	public void setExt2(String ext2) {
		this.ext2 = ext2;
	}
	public String getExt3() {
		return ext3;
	}
	public void setExt3(String ext3) {
		this.ext3 = ext3;
	}

    public String getExt4() {
        return ext4;
    }

    public void setExt4(String ext4) {
        this.ext4 = ext4;
    }

    public String getExt5() {
        return ext5;
    }

    public void setExt5(String ext5) {
        this.ext5 = ext5;
    }

    public String getExt6() {
        return ext6;
    }

    public void setExt6(String ext6) {
        this.ext6 = ext6;
    }

    public String getExt7() {
        return ext7;
    }

    public void setExt7(String ext7) {
        this.ext7 = ext7;
    }

    public Double getExt8(){
        return ext8;
    }

    public void setExt8(Double ext8){
        this.ext8 = ext8;
    }

    public String getFromvaliddatetime() {
		return fromvaliddatetime;
	}
	public void setFromvaliddatetime(String fromvaliddatetime) {
		this.fromvaliddatetime = fromvaliddatetime;
	}
	public String getTovaliddatetime() {
		return tovaliddatetime;
	}
	public void setTovaliddatetime(String tovaliddatetime) {
		this.tovaliddatetime = tovaliddatetime;
	}
	public String getFrominvaliddatetime() {
		return frominvaliddatetime;
	}
	public void setFrominvaliddatetime(String frominvaliddatetime) {
		this.frominvaliddatetime = frominvaliddatetime;
	}
	public String getToinvaliddatetime() {
		return toinvaliddatetime;
	}
	public void setToinvaliddatetime(String toinvaliddatetime) {
		this.toinvaliddatetime = toinvaliddatetime;
	}
	public String getGameid() {
		return gameid;
	}
	public void setGameid(String gameid) {
		this.gameid = gameid;
	}
	public Boolean getIstest() {
		return istest;
	}
	public void setIstest(Boolean istest) {
		this.istest = istest;
	}
	public String getGameidbytuijian() {
		return gameidbytuijian;
	}
	public void setGameidbytuijian(String gameidbytuijian) {
		this.gameidbytuijian = gameidbytuijian;
	}
	
}
